# Unknown error
error_message = "API tester error"
wrong_http_method_error_message = "wrong http method"
http_method_have_wrong_type = "get wrong type param"
# get data error
get_data_error_message = "API tester can't get api data error"
# API Http Method error
get_error_message = "API tester get error"
get_json_error_message = "API tester get json error"
put_error_message = "API tester put error"
delete_error_message = "API tester delete error"
post_error_message = "API tester post error"
head_error_message = "API tester head error"
options_error_message = "API tester options error"
patch_error_message = "API tester patch error"
session_error_message = "API tester session error"
# API response code error
response_code_error = "API tester get wrong response code"
# API response body error
response_body_error = "API tester get wrong response body"
# API response timeout error
response_timeout_error = "API tester timeout"
# API response history error
response_history_error = "API tester history error"
# API response encoding error
response_encoding_error = "API tester encoding error"
# API response cookies error
response_cookies_error = "API tester cookies error"
# API response headers error
response_headers_error = "API tester headers error"
# API response content error
response_content_error = "API tester content error"
# API response text error
response_text_error = "API tester text error"
# API execute action error
execute_action_error = "can't execute action"
# API json error
cant_find_json_error = "can't find json"
cant_save_json_error = "can't save json"
cant_reformat_json_error = "can't reformat json is type right?"
cant_find_element_in_json_error = "can't find element in json"
json_type_error = "json type error"
wrong_json_data_error = "can't parser json"
# API XML error
cant_read_xml_error = "can't read xml"
xml_type_error = "xml type error"
# Executor error
executor_data_error = "executor receive wrong data"
executor_list_error = "executor receive wrong data list is none or wrong type"
# API data check
status_code_error = "request status code error"
status_text_error = "request text error"
status_content_error = "request content error"
status_headers_error = "request headers error"
status_history_error = "request history error"
status_encoding_error = "request encoding error"
status_cookies_error = "request cookies error"
status_elapsed_error = "request elapsed error"
status_requests_method_error = "requests method error"
status_requests_url_error = "requests url error"
status_requests_body_error = "requests body error"
# HTML
html_generate_no_data_tag = "record is None"
# add command
add_command_exception_tag = "command value type should be as method or function"
# argparse
argparse_get_wrong_data = "argparse receive wrong data"
